==> zio-aws-iotthingsgraph_3-5.17.127.2-sources.jar: zio/aws/iotthingsgraph/model/CreateSystemTemplateResponse.scala <==
package zio.aws.iotthingsgraph.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateSystemTemplateResponse(
    summary: Option[zio.aws.iotthingsgraph.model.SystemTemplateSummary] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse = {
    import CreateSystemTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
      .builder()
      .optionallyWith(summary.map(value => value.buildAwsValue()))(_.summary)
      .build()
  }
  def asReadOnly
      : zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse.ReadOnly =
    zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse
      .wrap(buildAwsValue())
}
object CreateSystemTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse =
      zio.aws.iotthingsgraph.model
        .CreateSystemTemplateResponse(summary.map(value => value.asEditable))
    def summary
        : Option[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly]
    def getSummary: ZIO[
      Any,
      AwsError,
      zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly
    ] = AwsError.unwrapOptionField("summary", summary)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
  ) extends zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse.ReadOnly {
    override val summary
        : Option[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly] =
      scala
        .Option(impl.summary())
        .map(value =>
          zio.aws.iotthingsgraph.model.SystemTemplateSummary.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
  ): zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotthingsgraph_3-5.17.188.1-sources.jar: zio/aws/iotthingsgraph/model/CreateSystemTemplateResponse.scala <==
package zio.aws.iotthingsgraph.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateSystemTemplateResponse(
    summary: Optional[zio.aws.iotthingsgraph.model.SystemTemplateSummary] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse = {
    import CreateSystemTemplateResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
      .builder()
      .optionallyWith(summary.map(value => value.buildAwsValue()))(_.summary)
      .build()
  }
  def asReadOnly
      : zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse.ReadOnly =
    zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse
      .wrap(buildAwsValue())
}
object CreateSystemTemplateResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse =
      zio.aws.iotthingsgraph.model
        .CreateSystemTemplateResponse(summary.map(value => value.asEditable))
    def summary
        : Optional[zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly]
    def getSummary: ZIO[
      Any,
      AwsError,
      zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly
    ] = AwsError.unwrapOptionField("summary", summary)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
  ) extends zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse.ReadOnly {
    override val summary: Optional[
      zio.aws.iotthingsgraph.model.SystemTemplateSummary.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.summary())
      .map(value =>
        zio.aws.iotthingsgraph.model.SystemTemplateSummary.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotthingsgraph.model.CreateSystemTemplateResponse
  ): zio.aws.iotthingsgraph.model.CreateSystemTemplateResponse.ReadOnly =
    new Wrapper(impl)
}
